pub struct RangeBreak {
pub bounds: Option<[NumOrString; 2]>,
pub pattern: Option<NumOrString>,
pub values: Option<Vec<NumOrString>>,
pub dvalue: Option<u64>,
pub enabled: Option<bool>,
}Expand description
Struct representing a rangebreak for Plotly axes. See: https://plotly.com/python/reference/layout/xaxis/#layout-xaxis-rangebreaks
Fields
bounds: Option<[NumOrString; 2]>Sets the lower and upper bounds for this range break, e.g. [“sat”, “mon”]
pattern: Option<NumOrString>Sets the pattern by which this range break is generated, e.g. “day of week”
values: Option<Vec<NumOrString>>Sets the values at which this range break occurs. See Plotly.js docs for details.
dvalue: Option<u64>Sets the size of each range break in milliseconds (for time axes).
enabled: Option<bool>Sets whether this range break is enabled.
Implementations